pub struct DecoderImpl<R, C, Context>where
C: Config,{ /* private fields */ }Expand description
A Decoder that reads bytes from a given reader R.
This struct should rarely be used.
In most cases, prefer any of the decode functions.
The ByteOrder that is chosen will impact the endianness that is used to read integers out of the reader.
use bincode::de::{DecoderImpl, Decode};
let mut context = ();
let mut decoder = DecoderImpl::new(some_reader, bincode::config::standard(), &mut context);
// this u32 can be any Decode
let value = u32::decode(&mut decoder).unwrap();Implementations
Sourceimpl<R, C, Context> DecoderImpl<R, C, Context>
impl<R, C, Context> DecoderImpl<R, C, Context>
Sourcepub fn new(reader: R, config: C, context: Context) -> DecoderImpl<R, C, Context>
pub fn new(reader: R, config: C, context: Context) -> DecoderImpl<R, C, Context>
Construct a new Decoder