Module enc
fluentbase_
types
1.1.3
Module enc
Module Items
Modules
Structs
Traits
In fluentbase_
types::
bincode
fluentbase_types
::
bincode
Module
enc
Encoder-based structs and traits.
Modules

write
This module contains writer-based structs and traits.
Structs

Encoder
Impl
An Encoder that writes bytes into a given writer
W
.
Traits

Encode
Any source that can be encoded. This trait should be implemented for all types that you want to be able to use with any of the
encode_with
methods.
Encoder
Helper trait to encode basic types into.