decode_from_reader

Function decode_from_reader 

pub fn decode_from_reader<D, R, C>(
    reader: R,
    config: C,
) -> Result<D, DecodeError>
where D: Decode<()>, R: Reader, C: Config,
Attempt to decode a given type D from the given Reader.

See the config module for more information on configurations.