pub struct Compat<T>(pub T);Expand description
Wrapper struct that implements Decode and Encode on any type that implements serde’s DeserializeOwned and Serialize respectively.
This works for most types, but if you’re dealing with borrowed data consider using BorrowCompat instead.
Tuple Fields
0: TTrait Implementations
Sourceimpl<'de, T, Context> BorrowDecode<'de, Context> for Compat<T>where
T: DeserializeOwned,
impl<'de, T, Context> BorrowDecode<'de, Context> for Compat<T>where
T: DeserializeOwned,
Sourcefn borrow_decode<D>(decoder: &mut D) -> Result<Compat<T>, DecodeError>where
D: BorrowDecoder<'de>,
fn borrow_decode<D>(decoder: &mut D) -> Result<Compat<T>, DecodeError>where
D: BorrowDecoder<'de>,
Attempt to decode this type with the given BorrowDecode.
Sourceimpl<Context, T> Decode<Context> for Compat<T>where
T: DeserializeOwned,
impl<Context, T> Decode<Context> for Compat<T>where
T: DeserializeOwned,
Sourceimpl<T> Ord for Compat<T>where
T: Ord,
impl<T> Ord for Compat<T>where
T: Ord,
Sourceimpl<T> PartialOrd for Compat<T>where
T: PartialOrd,
impl<T> PartialOrd for Compat<T>where
T: PartialOrd,
impl<T> Eq for Compat<T>where
T: Eq,
impl<T> StructuralPartialEq for Compat<T>